@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2018 by the individuals mentioned in the source code history
+#   Copyright 2007-2019 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -18,3 +18,12 @@ require(OpenMx)
 ppml <- getOption('mxOptions')$UsePPML
 
 omxCheckTrue(!is.null(ppml) && ppml == "No")
+
+omxCheckError(mxOption(mxPath('one'), "bar"),
+              "The first argument to mxOption must be an MxModel, not 'MxPath'")
+
+mre <- mxOption(key="mvnRelEps")
+mxOption(key="mvnRelEps", value= mxOption(key="mvnRelEps") / 5)
+omxCheckEquals(mxOption(key="mvnRelEps"), mre / 5)
+mxOption(reset=TRUE)
+omxCheckEquals(mxOption(key="mvnRelEps"), mre)
