@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007-2019 by the individuals mentioned in the source code history
+ *  Copyright 2007-2021 by the individuals mentioned in the source code history
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -28,7 +28,7 @@
 //#undef PROTECT_WITH_INDEX
 //#undef UNPROTECT
 
-void string_to_Rf_error( const std::string& str) __attribute__ ((noreturn));
+void string_to_Rf_error( const char *str) __attribute__ ((noreturn));
 
 void exception_to_Rf_error( const std::exception& ex ) __attribute__ ((noreturn));
 
